@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,15 +10,16 @@
 
 
 package Mail::Message::Body::String;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Message::Body';
+use parent 'Mail::Message::Body';
 
 use strict;
 use warnings;
 
-use Carp;
+use Log::Report   'mail-message', import => [ qw/__x fault/ ];
+
 use Mail::Box::FastScalar ();
 
 #--------------------
@@ -31,7 +32,7 @@ sub _data_from_filename(@)
 
 	delete $self->{MMBS_nrlines};
 	open my $in, '<:raw', $filename
-		or $self->log(ERROR => "Unable to read file $filename for message body scalar: $!"), return;
+		or fault __x"unable to read file {name} for message body scalar", name => $filename;
 
 	my @lines = $in->getlines;
 	$in->close;
