@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,18 +10,18 @@
 
 
 package Mail::Message;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
 
 use strict;
 use warnings;
 
+use Log::Report   'mail-message', import => [ qw/__x error trace/ ];
+
 use Mail::Message::Head::Complete ();
 use Mail::Message::Field          ();
 
-use Carp         qw/croak/;
-
 #--------------------
 
 sub bounce(@)
@@ -48,8 +48,7 @@ sub bounce(@)
 	{	$rg = Mail::Message::Head::ResentGroup->new(@_);
 	}
 	else
-	{	$self->log(ERROR => "Method bounce requires To, Cc, or Bcc");
-		return undef;
+	{	error __x"method bounce requires To, Cc, or Bcc.";
 	}
 
 	$rg->set(Date => Mail::Message::Field->toDate) unless defined $rg->date;
