@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,13 +10,15 @@
 
 
 package Mail::Message;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
 
 use strict;
 use warnings;
 
+use Log::Report   'mail-message', import => [ qw/__x error trace/ ];
+
 use Mail::Message::Head::Complete  ();
 use Mail::Message::Body::Lines     ();
 use Mail::Message::Body::Multipart ();
@@ -45,7 +47,7 @@ sub rebuild(@)
 	foreach my $rule (@rules)
 	{	next if ref $rule;
 		$self->can($rule)
-			or $self->log(ERROR => "No rebuild rule '$rule' defined.\n"), return 1;
+			or error __x"no rebuild rule '{name}' defined.", name => $rule;
 	}
 
 	# Start off with the message
@@ -148,8 +150,8 @@ sub descendNested($@)
 	return $part if $newnested==$srcnested;
 
 	# Changes in the encapsulated message
-	my $newbody = ref($body)->new(based_on => $body, nested => $newnested);
-	my $rebuild = ref($part)->new(head => $part->head->clone, container => undef);
+	my $newbody   = (ref $body)->new(based_on => $body, nested => $newnested);
+	my $rebuild   = (ref $part)->new(head => $part->head->clone, container => undef);
 
 	$rebuild->body($newbody);
 	$rebuild;
@@ -220,8 +222,7 @@ sub textAlternativeForHtml($@)
 		or return $part;
 
 	my $container = $part->container;
-	my $in_alt    = defined $container
-					&& $container->mimeType eq 'multipart/alternative';
+	my $in_alt    = defined $container && $container->mimeType eq 'multipart/alternative';
 
 	return $part
 		if $in_alt && first { $_->body->mimeType eq 'text/plain' } $container->parts;
