@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,14 +10,16 @@
 
 
 package Mail::Message::Convert::HtmlFormatPS;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Message::Convert';
+use parent 'Mail::Message::Convert';
 
 use strict;
 use warnings;
 
+use Log::Report   'mail-message', import => [ qw// ];
+
 use Mail::Message::Body::String ();
 
 use HTML::TreeBuilder ();
@@ -28,7 +30,6 @@ use HTML::FormatPS    ();
 sub init($)
 {	my ($self, $args)  = @_;
 	my @formopts = map +($_ => delete $args->{$_}), grep m/^[A-Z]/, keys %$args;
-
 	$self->SUPER::init($args);
 
 	$self->{MMCH_formatter} = HTML::FormatPS->new(@formopts);
