@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,19 +10,20 @@
 
 
 package Mail::Message::Field;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Reporter';
+use parent 'Mail::Reporter';
 
 use strict;
 use warnings;
 
-use Carp;
-use Mail::Address        ();
-use IO::Handle           ();
-use Date::Format         qw/strftime/;
-use Hash::Case::Preserve ();
+use Log::Report      'mail-message', import => [ qw/__x error info panic warning/ ];
+
+use Mail::Address    ();
+use IO::Handle       ();
+use Date::Format     qw/strftime/;
+use Scalar::Util     qw/blessed/;
 
 our %_structured;  # not to be used directly: call isStructured!
 my $default_wrap_length = 78;
@@ -50,7 +51,7 @@ sub new(@)
 
 #--------------------
 
-sub length { length shift->folded }
+sub length { length $_[0]->folded }
 
 
 BEGIN {
@@ -65,7 +66,7 @@ BEGIN {
 }
 
 sub isStructured(;$)
-{	my $name  = ref $_[0] ? shift->name : $_[1];
+{	my $name  = $_[1] // (blessed $_[0] ? $_[0]->name : panic);
 	exists $_structured{lc $name};
 }
 
@@ -77,7 +78,8 @@ sub print(;$)
 }
 
 
-sub toString(;$) {shift->string(@_)}
+sub toString(;$) { shift->string(@_) }
+
 sub string(;$)
 {	my $self  = shift;
 	return $self->folded unless @_;
@@ -202,7 +204,7 @@ sub attribute($;$)
 	# broken messages do repeat them.  See github issue 20.  Apple Mail and
 	# Outlook will take the last of the repeated in such case, so we do that
 	# as well.
-	tie my %attrs, 'Hash::Case::Preserve', [ $self->attributes ];
+	my %attrs = $self->attributes;
 	@_ or return $attrs{$attr};
 
 	# set the value
@@ -248,7 +250,7 @@ sub toInt()
 	$self->body =~ m/^\s*(\d+)\s*$/
 		and return $1;
 
-	$self->log(WARNING => "Field content is not numerical: ". $self->toString);
+	warning __x"field content is not numerical: {content}", content => $self->toString;
 	undef;
 }
 
@@ -307,7 +309,8 @@ sub consume($;$)
 	my ($name, $body) = defined $_[1] ? @_ : split(/\s*\:\s*/, (shift), 2);
 
 	$name !~ m/[^\041-\071\073-\176]/
-		or Mail::Reporter->log(WARNING => "Illegal character in field name $name");
+		or warning __x"illegal character in field name '{name}'.", name => $name;
+panic $name if $name =~ m/[^\041-\071\073-\176]/;
 
 	#
 	# Compose the body.
@@ -390,7 +393,7 @@ sub fold($$;$)
 
 	my $lname = CORE::length($name);
 	$lname <= $wrap -5  # Cannot find a real limit in the spec
-		or $thing->log(ERROR => "Field name too long (max ".($wrap-5)."), in '$name'"), return ();
+		or error __x"field name too long (max {count}), in '{name}'.", count => $wrap - 5, name => $name;
 
 	my @folded;
 	while(1)
