@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,14 +10,16 @@
 
 
 package Mail::Message::Field::AddrGroup;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'User::Identity::Collection::Emails';
+use parent 'User::Identity::Collection::Emails';
 
 use strict;
 use warnings;
 
+use Log::Report   'mail-message', import => [ qw/__x error/ ];
+
 use Scalar::Util  qw/blessed/;
 
 #--------------------
@@ -48,8 +50,7 @@ sub coerce($@)
 			if $addr->isa('User::Identity::Collection::Emails');
 	}
 
-	$class->log(ERROR => "Cannot coerce a ".(ref($addr)|'string').  " into a $class");
-	();
+	error __x"cannot coerce a {type} into a {class}.", type => ref $addr // 'string', class => $class;
 }
 
 
