@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,14 +10,16 @@
 
 
 package Mail::Message::Field::DKIM;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Message::Field::Structured';
+use parent 'Mail::Message::Field::Structured';
 
 use warnings;
 use strict;
 
+use Log::Report   'mail-message', import => [ qw/__x error/ ];
+
 use URI      ();
 
 #--------------------
@@ -25,9 +27,7 @@ use URI      ();
 sub init($)
 {	my ($self, $args) = @_;
 	$self->{MMFD_tags} = +{ v => 1, a => 'rsa-sha256' };
-
 	$self->SUPER::init($args);
-	$self;
 }
 
 sub parse($)
@@ -53,8 +53,7 @@ sub produceBody()
 
 sub addAttribute($;@)
 {	my $self = shift;
-	$self->log(ERROR => 'No attributes for DKIM headers.');
-	$self;
+	error __x"no attributes for DKIM headers.";
 }
 
 
@@ -67,7 +66,6 @@ sub addTag($$)
 
 sub tag($) { $_[0]->{MMFD_tags}{lc $_[1]} }
 
-
 #--------------------
 
 sub tagAlgorithm() { $_[0]->tag('a') }
