@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,14 +10,16 @@
 
 
 package Mail::Message::Field::Date;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Message::Field::Structured';
+use parent 'Mail::Message::Field::Structured';
 
 use warnings;
 use strict;
 
+use Log::Report   'mail-message', import => [ qw/__x error/ ];
+
 use POSIX qw/mktime tzset/;
 
 #--------------------
@@ -25,10 +27,9 @@ use POSIX qw/mktime tzset/;
 my $dayname = qr/Mon|Tue|Wed|Thu|Fri|Sat|Sun/;
 my @months  = qw/Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec/;
 my %monthnr; { my $i; $monthnr{$_} = ++$i for @months }
-my %tz      = qw/
-	EDT -0400  EST -0500  CDT -0500  CST -0600
-	MDT -0600  MST -0700  PDT -0700  PST -0800
-	UT  +0000  GMT +0000/;
+my %tz      = qw/EDT -0400  EST -0500  CDT -0500  CST -0600
+				MDT -0600  MST -0700  PDT -0700  PST -0800
+				UT  +0000  GMT +0000/;
 
 sub parse($)
 {	my ($self, $string) = @_;
@@ -40,11 +41,11 @@ sub parse($)
 			( [A-Z][a-z][a-z]|[0-9][0-9]  ) \s+  # month
 			( (?: 19 | 20 | ) [0-9][0-9]  ) \s+  # year
 			( [0-1]?[0-9] | 2[0-3] )        \s*  # hour
-			    [:.] ( [0-5][0-9] )         \s*  # minute
+				[:.] ( [0-5][0-9] )         \s*  # minute
 			(?: [:.] ( [0-5][0-9] ) )?      \s*  # second (optional)
 			( [+-][0-9]{4} | [A-Z]+ )?           # zone
-			                                     # optionally followed by trash
-		/x or return undef;
+			\s*
+		$ /x or return undef;
 
 	$dn //= '';
 	$dn   =~ s/\s+//g;
@@ -69,8 +70,7 @@ sub date() { $_[0]->{MMFD_date} }
 
 sub addAttribute($;@)
 {	my $self = shift;
-	$self->log(ERROR => 'No attributes for date fields.');
-	$self;
+	error __x"no attributes for date fields.";
 }
 
 
