@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,15 +10,17 @@
 
 
 package Mail::Message::Field::Full;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Message::Field';
+use parent 'Mail::Message::Field';
 
 use strict;
 use warnings;
 use utf8;
 
+use Log::Report       'mail-message', import => [ qw/__x error warning/ ];
+
 use Encode            ();
 use MIME::QuotedPrint ();
 use Storable          qw/dclone/;
@@ -210,7 +212,7 @@ sub encode($@)
 	my ($charset, $lang, $encoding);
 
 	if($charset = $args{charset})
-	{	$self->log(WARNING => "Illegal character in charset '$charset'")
+	{	warning __x"illegal character in charset '{name}'.", name => $charset
 			if $charset =~ m/[\x00-\ ()<>@,;:"\/[\]?.=\\]/;
 	}
 	else
@@ -218,13 +220,13 @@ sub encode($@)
 	}
 
 	if($lang = $args{language})
-	{	$self->log(WARNING => "Illegal character in language '$lang'")
+	{	warning __x"illegal character in language '{name}'.", name => $lang
 			if $lang =~ m/[\x00-\ ()<>@,;:"\/[\]?.=\\]/;
 	}
 
 	if($encoding = $args{encoding})
 	{	unless($encoding =~ m/^[bBqQ]$/ )
-		{	$self->log(WARNING => "Illegal encoding '$encoding', used 'q'");
+		{	warning __x"illegal encoding '{name}', using 'q'.", name => $encoding;
 			$encoding = 'q';
 		}
 	}
