@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,16 +10,18 @@
 
 
 package Mail::Message::Field::URIs;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Message::Field::Structured';
+use parent 'Mail::Message::Field::Structured';
 
 use warnings;
 use strict;
 
-use URI          ();
-use Scalar::Util qw/blessed/;
+use Log::Report   'mail-message', import => [ qw/__x error/ ];
+
+use URI           ();
+use Scalar::Util  qw/blessed/;
 
 #--------------------
 
@@ -76,8 +78,7 @@ sub URIs() { @{ $_[0]->{MMFU_uris}} }
 
 sub addAttribute($;@)
 {	my $self = shift;
-	$self->log(ERROR => 'No attributes for URI fields.');
-	$self;
+	error __x"no attributes for URI fields.";
 }
 
 #--------------------
