@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,14 +10,16 @@
 
 
 package Mail::Message::Field::Unstructured;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Message::Field::Full';
+use parent 'Mail::Message::Field::Full';
 
 use strict;
 use warnings;
 
+use Log::Report   'mail-message', import => [ qw/__x warning/ ];
+
 #--------------------
 
 sub init($)
@@ -27,14 +29,10 @@ sub init($)
 	{	$args->{body} = $self->encode($args->{body}, %$args);
 	}
 
-	$self->SUPER::init($args) or return;
-
-	! defined $args->{attributes}
-		or $self->log(WARNING => "Attributes are not supported for unstructured fields");
-
-	! defined $args->{extra}
-		or $self->log(WARNING => "No extras for unstructured fields");
+	$self->SUPER::init($args);
 
+	! defined $args->{attributes} or warning __x"attributes are not supported for unstructured fields.";
+	! defined $args->{extra}      or warning __x"no extras for unstructured fields.";
 	$self;
 }
 
