@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,21 +10,25 @@
 
 
 package Mail::Message::Head::FieldGroup;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Reporter';
+use parent 'Mail::Reporter';
 
 use strict;
 use warnings;
 
+use Log::Report   'mail-message', import => [ qw/trace/ ];
+
+use Scalar::Util  qw/blessed/;
+
 #--------------------
 
 sub new(@)
 {	my $class = shift;
 
 	my @fields;
-	push @fields, shift while ref $_[0];
+	push @fields, shift while blessed $_[0];
 
 	$class->SUPER::new(@_, fields => \@fields);
 }
