@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,15 +10,15 @@
 
 
 package Mail::Message::Head::SpamGroup;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Message::Head::FieldGroup';
+use parent 'Mail::Message::Head::FieldGroup';
 
 use strict;
 use warnings;
 
-use Carp 'confess';
+use Log::Report   'mail-message', import => [ qw/panic/ ];
 
 #--------------------
 
@@ -33,8 +33,8 @@ sub fighter($;@)
 
 	if(@_)
 	{	my %args   = @_;
-		defined $args{fields} or confess "Spamfighters require fields\n";
-		defined $args{isspam} or confess "Spamfighters require isspam\n";
+		defined $args{fields} or panic "requires fields";
+		defined $args{isspam} or panic "requires isspam";
 		$fighters{$name} = \%args;
 
 		my @fields = map $_->{fields}, values %fighters;
@@ -90,11 +90,10 @@ sub from($@)
 
 	foreach my $type (@types)
 	{	$self = $class->new(head => $head) unless defined $self;
-		next unless $self->collectFields($type);
+		$self->collectFields($type) or next;
 
 		my %fighter = $self->fighter($type);
-		my ($software, $version)
-			= defined $fighter{version} ? $fighter{version}->($self, $head) : ();
+		my ($software, $version) = defined $fighter{version} ? $fighter{version}->($self, $head) : ();
 
 		$self->detected($type, $software, $version);
 		$self->spamDetected( $fighter{isspam}->($self, $head) );
@@ -108,8 +107,7 @@ sub from($@)
 
 sub collectFields($)
 {	my ($self, $set) = @_;
-	my %fighter = $self->fighter($set)
-		or confess "ERROR: No spam set $set.";
+	my %fighter = $self->fighter($set) or panic "no spam set $set";
 
 	my @names = map $_->name, $self->head->grepNames($fighter{fields});
 	$self->addFields(@names) if @names;
