@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Message version 3.023.
-# The POD got stripped from this file by OODoc version 3.06.
+# This code is part of Perl distribution Mail-Message version 4.00.
+# The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2001-2026 by Mark Overmeer.
+# This software is copyright (c) 2001-2025 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,14 +10,16 @@
 
 
 package Mail::Message::Replace::MailHeader;{
-our $VERSION = '3.023';
+our $VERSION = '4.00';
 }
 
-use base 'Mail::Message::Head::Complete';
+use parent 'Mail::Message::Head::Complete';
 
 use strict;
 use warnings;
 
+use Log::Report   'mail-message', import => [ qw/__x error panic/ ];
+
 #--------------------
 
 sub new(@)
@@ -28,7 +30,7 @@ sub new(@)
 
 sub init($)
 {	my ($self, $args) = @_;
-	defined $self->SUPER::init($args) or return;
+	$self->SUPER::init($args);
 
 	$self->modify($args->{Modify} || $args->{Reformat} || 0);
 	$self->fold_length($args->{FoldLength} || 79);
@@ -94,7 +96,7 @@ sub mail_from(;$)
 
 	my $choice = uc(shift);
 	$choice =~ /^(IGNORE|ERROR|COERCE|KEEP)$/
-		or die "bad Mail-From choice: '$choice'";
+		or error __x"bad Mail-From choice: '{pick}'.", pick => $choice;
 
 	$self->{MH_mail_from} = $choice;
 }
@@ -150,10 +152,10 @@ sub header(;$)
 }
 
 
-sub header_hashref($) { die "Don't use header_hashref!!!" }
+sub header_hashref($) { panic "Don't use header_hashref!!!" }
 
 
-sub combine($;$) { die "Don't use combine()!!!" }
+sub combine($;$) { panic "Don't use combine()!!!" }
 
 
 sub exists() { $_[0]->count }
